New statuses.

- [X] decide upon and implement "in progress"
- [X] decide upon and implement "cancelled"
- [X] decide upon and implement "blocked"
- [X] warnings for unknown formats
- [X] filter on incomplete
- [X] filter on in progress
- [X] filter on cancelled
- [X] filter on blocked
- [X] filter on complete
- [X] summarise individual states, but not combos
